aboutsummaryrefslogtreecommitdiffstats
path: root/epan
diff options
context:
space:
mode:
authorRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-10 07:55:52 +0000
committerRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-10 07:55:52 +0000
commitf5691aaba66582df86efe6f7aae8720b15c967a5 (patch)
treea9fa9e48c2e8f75a7d22273e6691d8a65387a2da /epan
parent102bb4be54f5ccd8536509bd2ffe99bd90612742 (diff)
add Bluetooth to the long protocol name
svn path=/trunk/; revision=18120
Diffstat (limited to 'epan')
-rw-r--r--epan/dissectors/packet-hci_h4.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-hci_h4.c b/epan/dissectors/packet-hci_h4.c
index 2cfbdf6f3d..78ee99736e 100644
--- a/epan/dissectors/packet-hci_h4.c
+++ b/epan/dissectors/packet-hci_h4.c
@@ -1,5 +1,5 @@
/* packet-hci_h4.c
* Routines for the HCI H4 dissection
*
* Copyright 2002, Christoph Scholz <scholz@cs.uni-bonn.de>
* From: http://affix.sourceforge.net/archive/ethereal_affix-3.patch
@@ -123,7 +123,7 @@ proto_register_hci_h4(void)
&ett_hci_h4,
};
- proto_hci_h4 = proto_register_protocol("HCI H4",
+ proto_hci_h4 = proto_register_protocol("Bluetooth HCI H4",
"HCI_H4", "hci_h4");
register_dissector("hci_h4", dissect_hci_h4, proto_hci_h4);
@@ -1,5 +1,5 @@
/* packet-hci_h4.c
- * Routines for the HCI H4 dissection
+ * Routines for the Bluetooth HCI H4 dissection
*
* Copyright 2002, Christoph Scholz <scholz@cs.uni-bonn.de>